@@ -32,3 +32,13 @@ test_that("set_seed", {
                     frac = 0.3)
   expect_equal(first, second)
 })
+
+
+test_that("surv_to_risk", {
+  expect_error(surv_to_risk(2), "0 <= x <= 1")
+  expect_error(surv_to_risk(matrix(0.5)), "increasing numeric")
+  expect_error(surv_to_risk(matrix(0.5, 1, 2, dimnames = list(NULL, 2:1))),
+              "increasing numeric")
+  expect_error(surv_to_risk(matrix(c(0.5, 0.8), 1, 2, FALSE, list(NULL, 1:2))),
+              "decreasing")
+})
\ No newline at end of file
