@@ -52,7 +52,7 @@ test_that("predict", {
   expect_is(p$surv, "matrix")
   expect_is(p$risk, "numeric")
   expect_equal(length(p$risk), 50)
-  expect_equal(dim(p$surv), c(50, 22))
+  expect_equal(dim(p$surv), c(50, 20))
 })
 
 test_that("predict distr6", {
@@ -61,8 +61,8 @@ test_that("predict distr6", {
   }
   p <- predict(fit, type = "all", distr6 = TRUE)
   expect_is(p, "list")
-  expect_is(p$surv, "VectorDistribution")
-  expect_equal(p$surv$properties$support$power, 50)
+  expect_is(p$surv, "Matdist")
+  expect_equal(nrow(distr6::gprm(p$surv, "cdf")), 50)
   p <- predict(fit, type = "survival")
   expect_is(p, "matrix")
 })
